
import { User } from "lucide-react";
import { Card } from "@/components/ui/card";

interface Conversation {
  id: string;
  contact: string;
  lastMessage: string;
  timestamp: string;
}

const mockConversations: Conversation[] = [
  {
    id: "1",
    contact: "+1 (555) 987-6543",
    lastMessage: "Thanks for your message",
    timestamp: "2 min ago",
  },
  {
    id: "2",
    contact: "+1 (555) 876-5432",
    lastMessage: "I'll get back to you shortly",
    timestamp: "1 hour ago",
  },
];

export function ConversationList() {
  return (
    <div className="space-y-4 p-4 animate-fadeIn">
      <div className="flex items-center justify-between mb-6">
        <h2 className="text-2xl font-semibold tracking-tight">Conversations</h2>
        <span className="text-sm text-muted-foreground">
          {mockConversations.length} active
        </span>
      </div>
      <div className="grid gap-4">
        {mockConversations.map((conversation) => (
          <Card
            key={conversation.id}
            className="p-4 transition-all hover:shadow-md cursor-pointer group"
          >
            <div className="flex items-center space-x-4">
              <div className="h-10 w-10 rounded-full bg-secondary flex items-center justify-center group-hover:bg-primary group-hover:text-white transition-colors">
                <User className="h-5 w-5" />
              </div>
              <div className="flex-1 min-w-0">
                <div className="flex justify-between items-start">
                  <h3 className="font-medium truncate">{conversation.contact}</h3>
                  <span className="text-xs text-muted-foreground whitespace-nowrap ml-2">
                    {conversation.timestamp}
                  </span>
                </div>
                <p className="text-sm text-muted-foreground truncate">
                  {conversation.lastMessage}
                </p>
              </div>
            </div>
          </Card>
        ))}
      </div>
    </div>
  );
}
