
import { useState } from "react";
import { Send } from "lucide-react";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Card } from "@/components/ui/card";
import { toast } from "sonner";
import { createClient } from "@supabase/supabase-js";

// Initialize Supabase client with proper error handling
const supabaseUrl = "https://ikmbnngahzcellthaysf.supabase.co";
const supabaseAnonKey = "YOUR_ANON_KEY_HERE"; // Replace this with your actual anon key

if (!supabaseUrl || !supabaseAnonKey) {
  throw new Error('Supabase URL and Anon Key are required');
}

const supabase = createClient(supabaseUrl, supabaseAnonKey);

export function MessageComposer() {
  const [message, setMessage] = useState("");
  const [phoneNumber, setPhoneNumber] = useState("");
  const [isSending, setIsSending] = useState(false);

  const handleSend = async () => {
    if (!message.trim() || !phoneNumber.trim()) {
      toast.error("Please enter both phone number and message");
      return;
    }

    console.log('Attempting to send message:', { phoneNumber, message });
    setIsSending(true);
    
    try {
      console.log('Invoking send-sms function...');
      const { data, error } = await supabase.functions.invoke('send-sms', {
        body: { phoneNumber, message }
      });

      console.log('Response from send-sms:', { data, error });

      if (error) {
        console.error('Supabase function error:', error);
        throw error;
      }

      toast.success("Message sent successfully!");
      setMessage("");
      setPhoneNumber("");
    } catch (error) {
      console.error('Detailed error:', error);
      toast.error("Failed to send message. Please try again.");
    } finally {
      setIsSending(false);
    }
  };

  return (
    <Card className="p-6 animate-fadeIn">
      <div className="space-y-4">
        <h2 className="text-2xl font-semibold tracking-tight">Send Message</h2>
        <div className="space-y-4">
          <div className="space-y-2">
            <label
              htmlFor="phone"
              className="text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70"
            >
              Phone Number
            </label>
            <Input
              id="phone"
              placeholder="Enter phone number..."
              value={phoneNumber}
              onChange={(e) => setPhoneNumber(e.target.value)}
              className="w-full"
              disabled={isSending}
            />
          </div>
          <div className="space-y-2">
            <label
              htmlFor="message"
              className="text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70"
            >
              Message
            </label>
            <Input
              id="message"
              placeholder="Type your message..."
              value={message}
              onChange={(e) => setMessage(e.target.value)}
              className="w-full"
              disabled={isSending}
            />
          </div>
          <Button
            onClick={handleSend}
            className="w-full group hover:shadow-md transition-all"
            disabled={isSending}
          >
            <Send className="mr-2 h-4 w-4 group-hover:scale-110 transition-transform" />
            {isSending ? "Sending..." : "Send Message"}
          </Button>
        </div>
      </div>
    </Card>
  );
}
